@@ -370,7 +370,7 @@ def _execute_GetPauliProduct(
         **kwargs) -> None:
     operation = cast(ops.PragmaGetPauliProduct, operation)
 
-    if np.isclose(np.sum(operation._pauli_product), 0):
+    if operation._pauli_product == []:
         classical_registers[operation._readout].register = [1, ]
         return None
     N = qureg.numQubitsRepresented
@@ -389,7 +389,7 @@ def _execute_GetPauliProduct(
             calculator=calculator,
             qubit_names=qubit_names,
             classical_registers=classical_registers)
-    qubits = [i for i in range(N) if operation._pauli_product[i] == 1]
+    qubits = [i for i in range(N) if i in operation._pauli_product]
     paulis = [3 for _ in qubits]
     pp = qcheat.calcExpecPauliProd().call_interactive(
         qureg=workspace, qubits=qubits, paulis=paulis, workspace=workspace_pp)
